@@ -103,8 +103,8 @@ struct spvm_env {
   void* object_ref_count_offset;
   void* object_basic_type_id_offset;
   void* object_type_dimension_offset;
-  void* object_type_runtime_type_offset;
-  void* object_type_flag_offset;
+  void* object_type_category_offset;
+  void* object_flag_offset;
   void* object_length_offset;
   void* byte_object_basic_type_id;
   void* short_object_basic_type_id;
@@ -216,7 +216,7 @@ struct spvm_env {
   void* (*get_type_name)(SPVM_ENV* env, void* object);
   SPVM_ENV* (*new_env)(SPVM_ENV* env);
   void (*free_env)(SPVM_ENV* env);
-  int32_t memory_blocks_count;
+  void* memory_blocks_count;
   const char* (*get_chars)(SPVM_ENV* env, void* string_object);
   int32_t (*die)(SPVM_ENV* env, const char* message, ...);
   void* (*new_object_by_name)(SPVM_ENV* env, const char* package_name, int32_t* exception_flag, const char* file, int32_t line);
